package com.srs.diagnostic.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.diagnostic.domain.DiaReportItems;
import com.srs.diagnostic.domain.DiaReportRelease;
import com.srs.diagnostic.domain.vo.DiaReportReleaseFillInVo;

/**
 * 报表发布Service接口
 *
 * @author srs
 * @date 2025-04-23
 */
public interface IDiaReportReleaseService extends IService<DiaReportRelease> {
    /**
     * 查询报表发布
     *
     * @param relId 报表发布主键
     * @return 报表发布
     */
    public DiaReportRelease selectDiaReportReleaseByRelId(Long relId);

    /**
     * 查询报表发布列表
     *
     * @param diaReportRelease 报表发布
     * @return 报表发布集合
     */
    List<DiaReportRelease> selectDiaReportReleaseList(DiaReportRelease diaReportRelease);

    /**
     * 新增报表发布
     *
     * @param diaReportRelease 报表发布
     * @return 结果
     */
    int insertDiaReportRelease(DiaReportRelease diaReportRelease);
    /**
     * 修改报表发布
     *
     * @param diaReportRelease 报表发布
     * @return 结果
     */
    int updateDiaReportRelease(DiaReportRelease diaReportRelease);

    /**
     * 批量删除报表发布
     *
     * @param relIds 需要删除的报表发布主键集合
     * @return 结果
     */
    int deleteDiaReportReleaseByRelIds(Long[] relIds);

    /**
     * 删除报表发布信息
     *
     * @param relId 报表发布主键
     * @return 结果
     */
    int deleteDiaReportReleaseByRelId(Long relId);

}
